# Test Coverage Report: excluded packages and modules

Generated: Mon 2015-06-08 11:27 AST

These packages and modules were excluded from the coverage analysis in `django.conf.settings.COVERAGE_MODULE_EXCLUDES` or they do not contain any executable statements:

- django.contrib.admin
- django.contrib.auth
- django.contrib.contenttypes
- django.contrib.sessions
- django.contrib.sitemaps
- django.contrib.sites
- forex.admin
- forex.migrations
- forex.settings
- forex.tests

Back to index.